@@ -87,7 +87,7 @@ class Exceptions:
 
 class DataSyncClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html)
     """
 
@@ -103,7 +103,7 @@ class DataSyncClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#can_paginate)
         """
 
@@ -111,7 +111,7 @@ class DataSyncClient(BaseClient):
         """
         Cancels execution of a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.cancel_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#cancel_task_execution)
         """
 
@@ -126,9 +126,9 @@ class DataSyncClient(BaseClient):
         SecurityGroupArns: List[str] = None
     ) -> CreateAgentResponseTypeDef:
         """
-        Activates an AWS DataSync agent that you have deployed on your host.
+        Activates an DataSync agent that you have deployed on your host.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.create_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.create_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_agent)
         """
 
@@ -143,7 +143,7 @@ class DataSyncClient(BaseClient):
         """
         Creates an endpoint for an Amazon EFS file system.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.create_location_efs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.create_location_efs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_efs)
         """
 
@@ -161,7 +161,7 @@ class DataSyncClient(BaseClient):
         """
         Creates an endpoint for an Amazon FSx for Windows File Server file system.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.create_location_fsx_windows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_fsx_windows)
         """
 
@@ -178,7 +178,7 @@ class DataSyncClient(BaseClient):
         Defines a file system on a Network File System (NFS) server that can be read
         from or written to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.create_location_nfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.create_location_nfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_nfs)
         """
 
@@ -198,7 +198,7 @@ class DataSyncClient(BaseClient):
         """
         Creates an endpoint for a self-managed object storage bucket.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.create_location_object_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_object_storage)
         """
 
@@ -215,7 +215,7 @@ class DataSyncClient(BaseClient):
         """
         Creates an endpoint for an Amazon S3 bucket.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.create_location_s3)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.create_location_s3)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_s3)
         """
 
@@ -235,7 +235,7 @@ class DataSyncClient(BaseClient):
         Defines a file system on a Server Message Block (SMB) server that can be read
         from or written to.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.create_location_smb)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.create_location_smb)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_location_smb)
         """
 
@@ -249,12 +249,13 @@ class DataSyncClient(BaseClient):
         Options: "OptionsTypeDef" = None,
         Excludes: List["FilterRuleTypeDef"] = None,
         Schedule: "TaskScheduleTypeDef" = None,
-        Tags: List["TagListEntryTypeDef"] = None
+        Tags: List["TagListEntryTypeDef"] = None,
+        Includes: List["FilterRuleTypeDef"] = None
     ) -> CreateTaskResponseTypeDef:
         """
         Creates a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.create_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.create_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#create_task)
         """
 
@@ -262,15 +263,15 @@ class DataSyncClient(BaseClient):
         """
         Deletes an agent.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.delete_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.delete_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#delete_agent)
         """
 
     def delete_location(self, *, LocationArn: str) -> Dict[str, Any]:
         """
-        Deletes the configuration of a location used by AWS DataSync.
+        Deletes the configuration of a location used by DataSync.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.delete_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.delete_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#delete_location)
         """
 
@@ -278,7 +279,7 @@ class DataSyncClient(BaseClient):
         """
         Deletes a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.delete_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.delete_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#delete_task)
         """
 
@@ -287,7 +288,7 @@ class DataSyncClient(BaseClient):
         Returns metadata such as the name, the network interfaces, and the status (that
         is, whether the agent is running or not) for an agent.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.describe_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.describe_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_agent)
         """
 
@@ -295,7 +296,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata, such as the path information about an Amazon EFS location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.describe_location_efs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.describe_location_efs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_efs)
         """
 
@@ -306,7 +307,7 @@ class DataSyncClient(BaseClient):
         Returns metadata, such as the path information about an Amazon FSx for Windows
         File Server location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.describe_location_fsx_windows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_fsx_windows)
         """
 
@@ -314,7 +315,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata, such as the path information, about an NFS location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.describe_location_nfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_nfs)
         """
 
@@ -324,7 +325,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata about a self-managed object storage server location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.describe_location_object_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_object_storage)
         """
 
@@ -332,7 +333,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata, such as bucket name, about an Amazon S3 bucket location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.describe_location_s3)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.describe_location_s3)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_s3)
         """
 
@@ -340,7 +341,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata, such as the path and user information about an SMB location.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.describe_location_smb)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.describe_location_smb)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_location_smb)
         """
 
@@ -348,7 +349,7 @@ class DataSyncClient(BaseClient):
         """
         Returns metadata about a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.describe_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.describe_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_task)
         """
 
@@ -358,7 +359,7 @@ class DataSyncClient(BaseClient):
         """
         Returns detailed metadata about a task that is being executed.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.describe_task_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.describe_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#describe_task_execution)
         """
 
@@ -372,7 +373,7 @@ class DataSyncClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#generate_presigned_url)
         """
 
@@ -380,10 +381,10 @@ class DataSyncClient(BaseClient):
         self, *, MaxResults: int = None, NextToken: str = None
     ) -> ListAgentsResponseTypeDef:
         """
-        Returns a list of agents owned by an AWS account in the AWS Region specified in
-        the request.
+        Returns a list of agents owned by an Amazon Web Services account in the Amazon
+        Web Services Region specified in the request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.list_agents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.list_agents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_agents)
         """
 
@@ -397,7 +398,7 @@ class DataSyncClient(BaseClient):
         """
         Returns a list of source and destination locations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.list_locations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.list_locations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_locations)
         """
 
@@ -407,7 +408,7 @@ class DataSyncClient(BaseClient):
         """
         Returns all the tags associated with a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_tags_for_resource)
         """
 
@@ -417,7 +418,7 @@ class DataSyncClient(BaseClient):
         """
         Returns a list of executed tasks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.list_task_executions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.list_task_executions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_task_executions)
         """
 
@@ -431,7 +432,7 @@ class DataSyncClient(BaseClient):
         """
         Returns a list of all the tasks.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.list_tasks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.list_tasks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#list_tasks)
         """
 
@@ -440,12 +441,13 @@ class DataSyncClient(BaseClient):
         *,
         TaskArn: str,
         OverrideOptions: "OptionsTypeDef" = None,
-        Includes: List["FilterRuleTypeDef"] = None
+        Includes: List["FilterRuleTypeDef"] = None,
+        Excludes: List["FilterRuleTypeDef"] = None
     ) -> StartTaskExecutionResponseTypeDef:
         """
         Starts a specific invocation of a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.start_task_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.start_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#start_task_execution)
         """
 
@@ -453,17 +455,17 @@ class DataSyncClient(BaseClient):
         self, *, ResourceArn: str, Tags: List["TagListEntryTypeDef"]
     ) -> Dict[str, Any]:
         """
-        Applies a key-value pair to an AWS resource.
+        Applies a key-value pair to an Amazon Web Services resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#tag_resource)
         """
 
     def untag_resource(self, *, ResourceArn: str, Keys: List[str]) -> Dict[str, Any]:
         """
-        Removes a tag from an AWS resource.
+        Removes a tag from an Amazon Web Services resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#untag_resource)
         """
 
@@ -471,7 +473,7 @@ class DataSyncClient(BaseClient):
         """
         Updates the name of an agent.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.update_agent)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.update_agent)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_agent)
         """
 
@@ -487,7 +489,7 @@ class DataSyncClient(BaseClient):
         Updates some of the parameters of a previously created location for Network File
         System (NFS) access.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.update_location_nfs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.update_location_nfs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_location_nfs)
         """
 
@@ -506,7 +508,7 @@ class DataSyncClient(BaseClient):
         Updates some of the parameters of a previously created location for self-managed
         object storage server access.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.update_location_object_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_location_object_storage)
         """
 
@@ -525,7 +527,7 @@ class DataSyncClient(BaseClient):
         Updates some of the parameters of a previously created location for Server
         Message Block (SMB) file system access.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.update_location_smb)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.update_location_smb)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_location_smb)
         """
 
@@ -537,12 +539,13 @@ class DataSyncClient(BaseClient):
         Excludes: List["FilterRuleTypeDef"] = None,
         Schedule: "TaskScheduleTypeDef" = None,
         Name: str = None,
-        CloudWatchLogGroupArn: str = None
+        CloudWatchLogGroupArn: str = None,
+        Includes: List["FilterRuleTypeDef"] = None
     ) -> Dict[str, Any]:
         """
         Updates the metadata associated with a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.update_task)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.update_task)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_task)
         """
 
@@ -552,21 +555,21 @@ class DataSyncClient(BaseClient):
         """
         Updates execution of a task.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Client.update_task_execution)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Client.update_task_execution)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/client.html#update_task_execution)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_agents"]) -> ListAgentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Paginator.ListAgents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListAgents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listagentspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_locations"]) -> ListLocationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Paginator.ListLocations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListLocations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listlocationspaginator)
         """
 
@@ -575,7 +578,7 @@ class DataSyncClient(BaseClient):
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtagsforresourcepaginator)
         """
 
@@ -584,13 +587,13 @@ class DataSyncClient(BaseClient):
         self, operation_name: Literal["list_task_executions"]
     ) -> ListTaskExecutionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskexecutionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tasks"]) -> ListTasksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.26/reference/services/datasync.html#DataSync.Paginator.ListTasks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListTasks)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskspaginator)
         """
